import dad_python
import pytest


def test_random_address():
    address = dad_python.random_address('US_UT')

    assert address['state'] == 'UT'


def test_list_addresses():
    addresses = dad_python.list_addresses('US_UT')

    assert len(addresses) == 100
    assert addresses[0]['state'] == 'UT'


def test_bad_data():
    with pytest.raises(KeyError) as error:
        _ = dad_python.random_address('BAD_DATA')

    assert '\'BAD_DATA\'' == str(error.value)


def test_list_iso_country_codes():
    with pytest.raises(NotImplementedError):
        _ = dad_python.list_iso_country_codes()



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

DEV_REQUIREMENTS = [
    'coveralls == 3.*',
    'flake8',
    'pytest == 6.*',
    'pytest-cov == 2.*',
]

setuptools.setup(
    name='dad-tool',
    version='0.1.1',
    description='Dummy Address Data (DAD) - Real addresses from all around the world.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='http://github.com/Justintime50/dad-python',
    author='Justintime50',
    license='MIT',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    extras_require={
        'dev': DEV_REQUIREMENTS,
    },
    python_requires='>=3.7',
)
